Servo Data Base

# Info on Servo Data Base

    1. Title: Servo Data

    2. Sources
       (a) Created by: Karl Ulrich (MIT) in 1986
       (b) Donor: Ross Quinlan
       (c) Date: May 1993

    3. Past Usage:

       1.  Quinlan, J.R., "Learning with continuous classes", Proc. 5th Australian
           Joint Conference on AI (eds A. Adams and L. Sterling), Singapore: World
           Scientific, 1992

       2.  Quinlan, J.R., "Combining instance-based and model-based learning",
           Proc. ML'93 (ed P.E. Utgoff), San Mateo: Morgan Kaufmann 1993

           Results on 10-way cross-validation:

           Method			Average		Relative
           ------			 |Err|		 Error
     				-------		--------

           Guessing mean		  1.15		  1.00
           Instance-based		   .52		   .26
           Regression		   .86		   .49
           Model trees		   .45		   .29
           Neural nets (G. Hinton)	   .30		   .11
           Regression+instances	   .48		   .20
           Model trees+instances	   .30		   .17
           NN+instances		   .29		   .11

    4. Relevant Information:

       Ross Quinlan:

       This data was given to me by Karl Ulrich at MIT in 1986.  I didn't
       record his description at the time, but here's his subsequent (1992)
       recollection:

         "I seem to remember that the data was from a simulation of a servo
         system involving a servo amplifier, a motor, a lead screw/nut, and a
         sliding carriage of some sort.  It may have been on of the
         translational axes of a robot on the 9th floor of the AI lab.  In any
         case, the output value is almost certainly a rise time, or the time
         required for the system to respond to a step change in a position set
         point."

       (Quinlan, ML'93)

       "This is an interesting collection of data provided by Karl
        Ulrich.  It covers an extremely non-linear phenomenon - predicting the
        rise time of a servomechanism in terms of two (continuous) gain settings
        and two (discrete) choices of mechanical linkages."

    5. Number of Instances: 167

    6. Number of Attributes: 4 + numeric class attribute

    7. Attribute information:

       1. motor: A,B,C,D,E
       2. screw: A,B,C,D,E
       3. pgain: 3,4,5,6
       4. vgain: 1,2,3,4,5
       5. class: 0.13 to 7.10

    8. Missing Attribute Values: None